import * as tf from '@tensorflow/tfjs';
import { BrowserFftFeatureExtractor } from './browser_fft_extractor';
import { RecognizerCallback, RecognizerParams, SpeechCommandRecognizer, SpeechCommandRecognizerResult, StreamingRecognitionConfig, TransferSpeechCommandRecognizer } from './types';
export declare const BACKGROUND_NOISE_TAG = "_background_noise_";
export declare const UNKNOWN_TAG = "_unknown_";
export declare class BrowserFftSpeechCommandRecognizer implements SpeechCommandRecognizer {
    static readonly VALID_VOCABULARY_NAMES: string[];
    static readonly DEFAULT_VOCABULARY_NAME: string;
    readonly MODEL_URL_PREFIX: string;
    private readonly SAMPLE_RATE_HZ;
    private readonly FFT_SIZE;
    private readonly DEFAULT_SUPPRESSION_TIME_MILLIS;
    model: tf.Model;
    readonly vocabulary: string;
    readonly parameters: RecognizerParams;
    protected words: string[];
    protected nonBatchInputShape: [number, number, number];
    private elementsPerExample;
    protected audioDataExtractor: BrowserFftFeatureExtractor;
    private transferRecognizers;
    private modelURL;
    private metadataURL;
    constructor(vocabulary?: string, modelURL?: string, metadataURL?: string);
    startStreaming(callback: RecognizerCallback, config?: StreamingRecognitionConfig): Promise<void>;
    ensureModelLoaded(): Promise<void>;
    private warmUpModel;
    private ensureMetadataLoaded;
    stopStreaming(): Promise<void>;
    isStreaming(): boolean;
    wordLabels(): string[];
    params(): RecognizerParams;
    modelInputShape(): tf.Shape;
    recognize(input: tf.Tensor | Float32Array): Promise<SpeechCommandRecognizerResult>;
    createTransfer(name: string): TransferSpeechCommandRecognizer;
    private freezeModel;
    private checkInputTensorShape;
}
